@@ -5,6 +5,7 @@
  *
  */
 #include <gkrellm2/gkrellm.h>
+#include <math.h>
 
 #define DEFAULT_STATION_ID      "YSSY"
 
@@ -55,11 +56,7 @@ static gchar        *weather_tips_text;
 typedef struct
 {
     GkrellmTextstyle   ts;
-    gint lbearing,
-	rbearing,
-	width,
-	ascent,
-	descent;
+    gint width, height, baseline, y_ink;
 }
 Extents;
 
@@ -109,11 +106,10 @@ static Options options;
 static void
 string_extents (gchar *string, Extents *ext)
 {
-    gdk_string_extents(ext->ts.font, string, &ext->lbearing, &ext->rbearing,
-            &ext->width, &ext->ascent, &ext->descent);
+    gkrellm_text_extents(ext->ts.font, string, strlen(string),
+			&ext->width, &ext->height, &ext->baseline, &ext->y_ink);
 }
 
-
 /* reference from wmWeather.c */
 static gboolean
 read_air ()
@@ -161,16 +157,15 @@ read_air ()
         fgets(line, 512, fp);
 
         fscanf(fp, "%lf", &air.temperature[0]);
-        air.temperature[1] = (air.temperature[0]-32.0)*5.0/9.0 + 0.5;
+        air.temperature[1] = (air.temperature[0]-32.0)*5.0/9.0;
         fscanf(fp, "%lf", &air.dew_point[0]);
-        air.dew_point[1] = (air.dew_point[0]-32.0)*5.0/9.0 + 0.5;
+        air.dew_point[1] = (air.dew_point[0]-32.0)*5.0/9.0;
 
         fscanf(fp, "%lf", &air.wind_chill[0]);
         air.wind_chill_avail = (air.wind_chill[0] < -900.0) ? 0 : 1;
-        air.wind_chill[1] = (air.wind_chill[0]-32.0)*5.0/9.0 + 0.5;
+        air.wind_chill[1] = (air.wind_chill[0]-32.0)*5.0/9.0;
 
         fscanf(fp, "%lf", &air.pressure[0]);
-        air.pressure[0] += 0.005;
         air.pressure[1] = air.pressure[0] * 25.4;
         air.pressure[2] = air.pressure[0] * 3.38639;
         air.pressure[3] = air.pressure[0] * 33.8639;
@@ -196,8 +191,8 @@ read_air ()
     setlocale(LC_NUMERIC, oldlocale);
     g_free(oldlocale);
 
-    name_xoff = -gdk_string_width(gkrellm_default_font(1), air.name);
-    sky_cond_xoff = -gdk_string_width(gkrellm_default_font(1), air.sky_cond);
+    name_xoff = -gkrellm_gdk_string_width(gkrellm_default_font(1), air.name);
+    sky_cond_xoff = -gkrellm_gdk_string_width(gkrellm_default_font(1), air.sky_cond);
 
     // Change tooltips
     if (weather_tips != NULL)
@@ -306,28 +301,27 @@ draw_panel ()
             }
             break;
         case WIN_DISPLAY:
-            wdx = (int)((air.wind_direction + 360.0 + 11.25) / 22.5) % 16;
+            wdx = lrintf((air.wind_direction + 360.0) / 22.5) % 16;
             gkrellm_draw_decal_text(panel, decal_wind_direction,
                     compress_direction[wdx], wdx);
             if (options.metric && options.windspeed_unit == 3)
             {
-                v = (int)air.wind_speed[3];
+                v = lrintf(air.wind_speed[3]);
                 sprintf(l2, "F%d", v);
                 v += 1000;   /* to distinguish redraws */
             }
             else
             {
-                v = (int)air.wind_speed[
-                         options.metric ? options.windspeed_unit : 0];
-                sprintf(l2, "%d", v);
+                v = lrintf(air.wind_speed[options.metric ? options.windspeed_unit : 0]);
+                sprintf(l2, "%.0d", v);
             }
             gkrellm_draw_decal_text(panel, decal_wind_speed, l2, v);
             break;
         case DEW_DISPLAY:
-            v = (int)air.dew_point[options.metric];
+            v = lrintf(air.dew_point[options.metric]);
             sprintf(l1, "%+4d", v);
             gkrellm_draw_decal_text(panel, decal_dew_point, l1, v);
-            v = (int)air.pressure[options.metric ? options.pressure_unit : 0];
+            v = lrintf(air.pressure[options.metric ? options.pressure_unit : 0]);
             sprintf(l2, "%4d", v);
             gkrellm_draw_decal_text(panel, decal_pressure, l2, v);
             units = options.metric ? "C" : "F";
@@ -335,10 +329,10 @@ draw_panel ()
             break;
         case TEM_DISPLAY:
         default:
-            v = (int)air.temperature[options.metric];
+            v = lrintf(air.temperature[options.metric]);
             sprintf(l1, "%+4d", v);
             gkrellm_draw_decal_text(panel, decal_temperature, l1, v);
-            v = (int)air.humidity;
+            v = lrintf(air.humidity);
             sprintf(l2, "%3d", v);
             gkrellm_draw_decal_text(panel, decal_humidity, l2, v);
             units = options.metric ? "C" : "F";
